import { Mutation, useMutation } from 'react-apollo'
import * as Yup from 'yup'

import { useFormHandler, TextInput } from '../form/forms'
import { USER_SIGNUP } from './graphql'
import { SyntheticEvent } from 'react'


const initialValues = {
  name: 'Tomi',
  email: 'tomi@cvetic.ch',
  password: '1234',
  passwordAgain: '1234'
}

const validationScheme = Yup.object({
  name: Yup.string()
    .required('Required')
    .max(40, 'Must be 40 characters or less'),
  email: Yup.string()
    .email('Invalid email address')
    .required('Required'),
  password: Yup.string()
    .min(4, 'Must have at least 8 characters'),
  passwordAgain: Yup.string()
    .oneOf([Yup.ref('password'), null], 'Passwords must match')
})


const SignupForm = () => {

  const { inputProps, values } = useFormHandler(initialValues, validationScheme.isValid)
  const [userSignup, { loading, error }] = useMutation(USER_SIGNUP)

  return (
    <form onSubmit={async (event: SyntheticEvent) => {
      event.preventDefault()
      try {
        const data = await userSignup({ variables: values })
      } catch (error) {
        console.log(error)
      }
    }}>
      <TextInput label='Name' {...inputProps('name')} />
      <TextInput label='Email' {...inputProps('email')} />
      <TextInput label='Password' {...inputProps('password')} />
      <TextInput label='Repeat password' {...inputProps('passwordAgain')} />
      <button type='reset' disabled={loading}>Reset</button>
      <button type='submit' disabled={loading}>Sign Up!</button>

      <style jsx>
        {`
            select, input {
              color: rgba(0,0,127,1);
            }

            .error {
              font-size: 12px;
              color: rgba(127,0,0,1);
              width: 400px;
              margin-top: 0.25rem;
            }

            .error:before {
              content: "❌ ";
              font-size: 10px;
            }

            label {
              color: red;
              margin-top: 1rem;
            }
          `}
      </style>
    </form>
  )
}

export default SignupForm
